"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnimationAttachment = void 0;
const inspectable_1 = require("inspectable");
const photo_size_1 = require("../structures/photo-size");
const file_attachment_1 = require("./file-attachment");
/**
 * This object represents an animation file
 * (GIF or H.264/MPEG-4 AVC video without sound).
 */
// TODO: extended: ['fileId', 'fileUniqueId']
let AnimationAttachment = class AnimationAttachment extends file_attachment_1.FileAttachment {
    constructor() {
        super(...arguments);
        this.attachmentType = 'animation';
    }
    /** Video width as defined by sender */
    get width() {
        return this.payload.width;
    }
    /** Video height as defined by sender */
    get height() {
        return this.payload.height;
    }
    /** Duration of the video in seconds as defined by sender */
    get duration() {
        return this.payload.duration;
    }
    /** Animation thumbnail as defined by sender */
    get thumbnail() {
        const { thumbnail } = this.payload;
        if (!thumbnail) {
            return;
        }
        return new photo_size_1.PhotoSize(thumbnail);
    }
    /** Original animation filename as defined by sender */
    get fileName() {
        return this.payload.file_name;
    }
    /** MIME type of the file as defined by sender */
    get mimeType() {
        return this.payload.mime_type;
    }
    /** File size */
    get fileSize() {
        return this.payload.file_size;
    }
    toJSON() {
        return this.payload;
    }
};
__decorate([
    (0, inspectable_1.Inspect)()
], AnimationAttachment.prototype, "width", null);
__decorate([
    (0, inspectable_1.Inspect)()
], AnimationAttachment.prototype, "height", null);
__decorate([
    (0, inspectable_1.Inspect)()
], AnimationAttachment.prototype, "duration", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AnimationAttachment.prototype, "thumbnail", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AnimationAttachment.prototype, "fileName", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AnimationAttachment.prototype, "mimeType", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AnimationAttachment.prototype, "fileSize", null);
AnimationAttachment = __decorate([
    (0, inspectable_1.Inspectable)()
], AnimationAttachment);
exports.AnimationAttachment = AnimationAttachment;
