"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GiveawayWinners = void 0;
const inspectable_1 = require("inspectable");
const chat_1 = require("./chat");
const user_1 = require("./user");
/** This object represents a message about the completion of a giveaway with public winners. */
let GiveawayWinners = class GiveawayWinners {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** The chat that created the giveaway */
    get chat() {
        return new chat_1.Chat(this.payload.chat);
    }
    /** Identifier of the message with the giveaway in the chat */
    get messageId() {
        return this.payload.giveaway_message_id;
    }
    /** Point in time (Unix timestamp) when winners of the giveaway were selected */
    get winnersSelectionDate() {
        return this.payload.winners_selection_date;
    }
    /** Total number of winners in the giveaway */
    get winnerCount() {
        return this.payload.winner_count;
    }
    /** List of up to 100 winners of the giveaway */
    get winners() {
        return this.payload.winners.map(w => new user_1.User(w));
    }
    /** The number of other chats the user had to join in order to be eligible for the giveaway */
    get additionalChatCount() {
        return this.payload.additional_chat_count;
    }
    /** The number of months the Telegram Premium subscription won from the giveaway will be active for */
    get premiumSubscriptionMonthCount() {
        return this.payload.premium_subscription_month_count;
    }
    /** Number of undistributed prizes */
    get unclaimedPrizeCount() {
        return this.payload.unclaimed_prize_count;
    }
    /** `true`, if only users who had joined the chats after the giveaway started were eligible to win */
    get onlyNewMembers() {
        return this.payload.only_new_members;
    }
    /** `true`, if the giveaway was canceled because the payment for it was refunded */
    wasRefunded() {
        return this.payload.was_refunded;
    }
    /** Description of additional giveaway prize */
    get prizeDescription() {
        return this.payload.prize_description;
    }
    toJSON() {
        return this.payload;
    }
};
__decorate([
    (0, inspectable_1.Inspect)()
], GiveawayWinners.prototype, "winnersSelectionDate", null);
__decorate([
    (0, inspectable_1.Inspect)()
], GiveawayWinners.prototype, "winnerCount", null);
__decorate([
    (0, inspectable_1.Inspect)()
], GiveawayWinners.prototype, "winners", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], GiveawayWinners.prototype, "additionalChatCount", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], GiveawayWinners.prototype, "premiumSubscriptionMonthCount", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], GiveawayWinners.prototype, "onlyNewMembers", null);
__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], GiveawayWinners.prototype, "wasRefunded", null);
__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], GiveawayWinners.prototype, "prizeDescription", null);
GiveawayWinners = __decorate([
    (0, inspectable_1.Inspectable)()
], GiveawayWinners);
exports.GiveawayWinners = GiveawayWinners;
